#
# spec file for package qtermwidget
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define  qt_ver 6
%define  sover  2
Name:           qtermwidget
Version:        2.1.0
Release:        2.1
Summary:        The terminal widget for QTerminal
License:        BSD-3-Clause AND GPL-2.0-or-later AND LGPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/lxqt/qtermwidget
Source:         %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake
%if 0%{?suse_version} < 1600
BuildRequires:  utempter-devel
%endif
BuildRequires:  utf8proc-devel
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Widgets) >= 6.6.0
BuildRequires:  cmake(lxqt2-build-tools) >= 2.1.0

%description
QTermWidget is an open-source project originally based on the KDE4 Konsole
application, but it took its own direction later on. The main goal of this
project is to provide a Unicode-enabled, embeddable Qt widget for using as
a built-in console (or terminal emulation widget).

%package -n libqtermwidget%{qt_ver}-%{sover}
Summary:        The terminal widget for QTerminal
Group:          Development/Libraries/C and C++
Requires:       %{name}-data >= %{version}

%description -n libqtermwidget%{qt_ver}-%{sover}
QTermWidget is an open-source project originally based on the KDE4 Konsole
application, but it took its own direction later on. The main goal of this
project is to provide a Unicode-enabled, embeddable Qt widget for using as
a built-in console (or terminal emulation widget).

%package data
Summary:        QTermWidget data package
Group:          Development/Libraries/C and C++
Requires:       libqtermwidget%{qt_ver}-%{sover} = %{version}
BuildArch:      noarch

%description data
Data files for qtermwidget library.

%package devel
Summary:        QTermWidget devel package
Group:          Development/Libraries/C and C++
Requires:       libqtermwidget%{qt_ver}-%{sover} = %{version}

%description devel
Development environment for qtermwidget library.

%prep
%autosetup

%build
%cmake_qt6 \
    -DUSE_UTF8PROC=ON \
    -DQTERMWIDGET_USE_UTEMPTER=ON
%{qt6_build}

%install
%{qt6_install}

%ldconfig_scriptlets -n libqtermwidget%{qt_ver}-%{sover}

%files -n libqtermwidget%{qt_ver}-%{sover}
%doc AUTHORS CHANGELOG README.md
%{_libdir}/libqtermwidget%{qt_ver}.so.*
%license LICENSE*

%files data
%{_datadir}/qtermwidget%{qt_ver}

%files devel
%{_includedir}/qtermwidget%{qt_ver}
%{_libdir}/libqtermwidget%{qt_ver}.so
%{_libdir}/pkgconfig/qtermwidget%{qt_ver}.pc
%{_libdir}/cmake/qtermwidget%{qt_ver}

%changelog
* Thu Jan 16 2025 Thorsten Kukuk <kukuk@suse.com>
- Disable libutempter, it doesn't work anymore with the switch
  from utmp to systemd-logind
* Wed Nov  6 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.1.0:
  * Pre-release changes (#561)
  * Silenced old compilation warnings
  * Weblate commits (#560)
  * Weblate commits (#556)
  * Pre-release changes (#555)
  * Fixed conversion to `std::wstring` (#554)
  * Use lxqt-build-tools package (#551)
  * Weblate commits (#553)
  * Pre-release changes (#550)
  * Fixed comparison of pointer addition with NULL (#549)
* Thu Jun 27 2024 Shawn Dunn <sfalken@opensuse.org>
- Update to 2.0.1:
  * Fixed visual artifacts due to a mistake about conversion to
    std::wstring in Qt6 Port.
* Sat May 18 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to 2.0.0:
  * Ported to Qt6.
* Mon Nov  6 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.4.0:
  * TERM env variable is set to xterm-256color when not set with
    QTermWidget::setEnvironment().
  * getForegroundProcessId() is added to QTermWidget class to allow
    terminal apps to check if the user has started a process in the
    shell and alert them.
  * A great amount of code cleanup.
  * Falcon color scheme is added.
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * A problem is fixed in switching the color scheme between dark
    and light.
  * Prevented a crash on splitting the terminal under
    `kwin_wayland`
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Enabled Bidi rendering by default.
  * Made text DND follow the settings for newline trimming and
    multiline prompt.
  * Allow `QTermWidget` to be used as a Qt Plugin.
* Tue Apr 26 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Handled the zero history size.
  * Added API documentation and followed the naming convention in some
  places of the code.
  * Return focus to the terminal on closing the search bar.
  * Code cleanup and enhancement.
* Tue Apr 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Fix a rpmlint error:
  * libqtermwidget5-0.x86_64: E: shlib-policy-name-error
    SONAME: libqtermwidget5.so.1, expected package suffix: 1
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Bumped minimum required Qt version to 5.15.
  * Fixed crash under (Plasma) Wayland on opening tab and splitting.
  * Quote drag-and-drop file names.
  * Backported CNL and CPL support from Konsole.
  * Some code cleanup.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Dropped the support for KDE3 color scheme formats.
  * Properly implemented the "Action after paste" feature.
  * Added modes for background image. How background images are
    drawn is changed and manual reconfiguration may be needed.
  See docs/configuration.md for more details.
  * Added a method to disable bracketed paste mode.
  * Fixed the execution after pasting when Ctrl is hold.
* Sun Nov 15 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.1:
  * Bumped version to 0.16.1, for a point release of qterminal.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Use qAsConst.
  * Don't search application dir for keyboard and scheme data.
  * Use Q_EMIT to call signals, instead of the emit keyword.
  * Dropped the deprecated class QLinkedList.
  * Don't use 0/nullptr to initialize QFlags.
  * Fixed ColorEntry copy operator.
  * Disabled the use of copy constructors and assignment operators.
  * Check for successful ioctl() calls by testing that the call
    did not return -1.
  * Fix find_package() developer warning in cmake.
  * Use const references wherever possible.
  * Handle keyboard commands properly.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Keyring change
  * Renamed qtermwidget.keyring to qtermwidget-qt5.keyring
  * Changed key to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * Fixes for macOS.
  * Fixed the PyQt5 binding with Qt ≥ 5.11.
  * Fixed a memory access violation.
  * Added saveHistory to QTermWidget.
  * Don't set the selection clipboard if it's unsupported.
  * Announce truecolor support via COLORTERM.
  * Fixed the numpad handling and added entries for numpad 5.
  * Allow to disable drawing line characters.
  * Fixed compilation on NetBSD.
  * Fixed flickering on font change.
  * Select all text when opening search-bar.
  * Fixed search-bar's light text over white background with dark themes.
  * Fixed build with LLVM/clang.
  * Several fixes.
* Fri Mar  1 2019 mvetter@suse.com
- Update to 0.14.1:
  * Only translations was changed.
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Clarify the licenses used in qtermwidget and added the missed root licenses
  * Ensure .bash_history is correctly written out
  * Make Backspace behaves the same as xterm
  * Fixed visual glitches in the search bar
  * Redraw cursor after cursor type changed
  * Fix handling of ST (String Terminator) for OSC (Operating System Commands)
* Tue May 22 2018 mvetter@suse.com
- Add asc and keyring file
- Update to 0.9.0:
  * Take transient scrollbars into account
  * CMake: Prevent in-source builds
  * Refactor and fixes Python binding
  * kptyprocess: Try to terminate the shell process
  * New color scheme: Ubuntu inspired
  * Fixed some github pathes in uris
  * Add a comment for potential future breakage
  * Use wstring in TerminalCharacterDecoder for UCS-4 compatibility
  * Support UTF-32 characters correctly
  * Fix "bold and intensive" colors
  * New color scheme: Tango (#167)
  * Finish SGR mouse protocol (1006)
  * Fix build of example with latest lxqt-build-tools
  * Expose bracket text function
  * Drop Qt foreach.
  * Revert deletions in .sip file
  * fix python bindings
  * Expose terminal size hint API
  * Remove class name
  * Return something
  * Expose bidi option
  * Add an example for remote terminal
  * Makes the use of libutempter optional
  * Fix behavior of scroll up (SU)
  * Install cmake files in LIBDIR as they are architecture dependend
  * Check if utempter.h header exists (mainly for FreeBSD)
* Wed Oct 25 2017 mvetter@suse.com
- Add BuildRequire:
  * utf8proc-devel to have better utf8 support
  * Qt5LinguistTools new dependency
- Use switch to not use git to pull translations
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.8.0:
  * FIX: #46 fix vertical font truncation
  * bump versions
  * Really fallback to /bin/sh when $SHELL is missing or invalid
  * README: don't recommend building from source
  * Improve README
  * Don't export github templates
  * Support REP escape sequence defined in ECMA-48, section 8.3.103
  * Fix build issue related to utmpx in Mac OSX Sierra
  * Remove the deprecation notice
  * Handle DECSCUSR signals
  * Copied issue template
  * Update building instructions
  * Require Qt 5.6+
  * This commit allows the consumer of qtermwidget to capture the (#111)
  * Allow the terminal display to be smaller than the size hint (#123)
  * Backport Vt102 emulation fixes (#113)
  * Backport the default.keytab from Konsole
  * Fixes (#122)
  * Updated README, Added support for PyQT 5.7
  * Fix memory leak in hotspot (URLs & emails) detection
  * Adds superbuild support
  * Use target_compile_definitions() instead of add_definitions()
  * Update find_package() documentation
  * Use the lxqt_create_pkgconfig_file
  * Improve lxqt_translate_ts() use
  * Adds COMPONENT to the install files
  * Renames test app to example. Make it work
  * Drop include_directories() for in tree dirs
  * Use the CMake Targets way
  * Pack Utf8Proc stuff
  * Adds export header
  * Use LXQtCompilerSettings
  * Packs compile definitions
  * Adds package version file
  * Removes Qt4 stuff
  * Add translation mechanism
  * Use const iterators when possible.
  * Enable strict iterators for debug builds
  * TerminalDisplay: Make resizing "Size" translatable
  * Exposes receivedData signal to users of QTermWidget
  * Exposes sessions autoClose property to QTermWidget
* Wed Jan  4 2017 dap.darkness@gmail.com
- Updated to 0.7.1:
  * Bump patch version (#105);
  * Added a modified Breeze color scheme (#104);
  * Accept hex color strings as well (#101);
  * Remove the stale lib/README (#102);
  * Implement background images (#95);
  * Implement other BOX DRAWING characters (#98);
  * Preparations for context menu actions on URLs (#97);
  * Drop the ancient wcwidth impl. and use utf8proc if possible;
  * Remove widget size checks in setVTFont() (#86);
  * Delete unused tooltip code (#81);
  * Fix size of the array passed to memset() (#79).
* Sun Sep 25 2016 dap.darkness@gmail.com
- Updated to 0.7.0:
  * Remove support for Qt <= 5.4;
  * Remove Designer plugin;
  * Check CHANGELOG for additional information.
- %%%%cmake macro.
* Tue May 17 2016 jengelh@inai.de
- Trim storytelling from description.
* Sun Feb 28 2016 dap.darkness@gmail.com
- Updated to 0.6.0:
  * Full Qt 5 support;
  * Drag & Drop support;
  * Lots of bugfixes and cleanups.
* Wed Sep 17 2014 dap.darkness@gmail.com
- Initial build.
